==> osdplay-0.3.tgz: osdplay-0.3/osdplay.c <==
/*
osdplay  copyright 2003 Jan Panteltje.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#include "osdplay.h"
#include "osdplay.h"

FILE *optr;

int print_usage()
{
fprintf(stdout, "\
Usage:          osdplay [-d] [-h] [-l] [-o offset_milliseconds] -p projectname [-s]\n\n\
-b              force black and white subtitles\n\
-d              debug (prints functions and arguments)\n\
-h              help (this help)\n\
-l              activate logo\n\
-o offset       offset in milliseconds\n\
-p projectname  projectname, filename used is ~/.subtitles/projectname/projectname.sub\n\
-s factor       factor is speed multiplier (float) example -s 1.003\n\
-t              fast test mode (no sync)\n\
-u devicename   name of OSD device, for example /dev/ost/osd0 (default is /dev/ost/osdn, n = 0 to 9)\n\
-v              input file in in vob2sub format (made with submux-dvd)\n\
");

return 1;
} /* end function print_usage */


main(int argc, char **argv)
{
int a, b, c, i;
char temp[4096];
char *buffer;
size_t buffsize;
int fmux;
unsigned long lstart_usecs, lcurrent_usecs, ldiff_usecs;
unsigned long min_ldiff_usecs, max_ldiff_usecs;
unsigned long ltotal_usecs;

fprintf(stdout, "\nPanteltje osdplay-%s\n\n", VERSION);

/* defaults */
speed_factor = 1.0;
/* end defaults */

while(1)
	{
	a = getopt(argc, argv, "bdhlo:p:s:tvu:");
	if(a == -1) break;

	switch(a)
		{
        case -1:
        	break;
		case 'b':
			bw_flag = 1;
			break;
		case 'd':
			debug_flag = 1;
			break;
		case 'h':
			print_usage();
			exit(1);
			break;
		case 'l':
			logo_flag = 1;
			break;
		case 'o':
			offset_milliseconds = atol(optarg);
			break;
		case 'p':
			selected_project = strsave(optarg);
			if(! selected_project)
				{
				fprintf(stdout, "could not alloce space for selected_project aborting\n");

				exit(1);
				}			
			break;
		case 's':
			speed_factor = atof(optarg);
			if(speed_factor <= 0.0)
				{
				fprintf(stdout,\
				"-c flag: speed_factor=%f, but cannot be zero or negative, aborting.\n",\
				speed_factor);
				
				exit(1);
				}

			break;
		case 't':
			no_sync_flag = 1;
			break;
		case 'u':
			osd_device_name = strsave(optarg);
			if(! osd_device_name)
				{
				fprintf(stdout, "Could not allocate space for osd_device_name, aborting\n");
				exit(1);
				}

			break;
		case 'v':
			vob2sub_flag = 1;
			break;
		case '?':
			if (isprint(optopt) )
 				{
 				fprintf(stdout, "Unknown option `-%c'.\n", optopt);
 				}
			else
				{
				fprintf(stdout, "Unknown option character `\\x%x'.\n",\
				optopt);
				}
			print_usage();

			exit(1);
			break;			
		default:
			print_usage();

			exit(1);
			break;
		}/* end switch a */
	}/* end while getopt() */

if(! selected_project && ! logo_flag)
	{
	print_usage();

	exit(1);
	}

/* report special situations */
if(offset_milliseconds != 0) fprintf(stdout, "using delay %ld milliseconds\n", offset_milliseconds);
if(speed_factor != 1.0) fprintf(stdout, "using speed %f x\n", speed_factor);
if(bw_flag) fprintf(stdout, "forcing black and white subtitles\n");
if(no_sync_flag) fprintf(stdout, "using test mode!!!\n");
if(vob2sub_flag) fprintf(stdout, "expecting vob2sub format .sub file\n");
if(logo_flag) fprintf(stdout, "logo activated\n");
if(debug_flag) fprintf(stdout, "debug_mode activated\n");
if(osd_device_name) fprintf(stdout, "using osd device %s\n", osd_device_name); 
userinfo = getpwuid(getuid() );

/* get home directory */ 
home_dir = strsave(userinfo -> pw_dir);
user_name = strsave(userinfo -> pw_name);

start_timeval = malloc(sizeof(struct timeval) );
if(! start_timeval)
	{
	fprintf(stdout, "could not allocate space for start_timeval\n");

	exit(1);
	}

current_timeval = malloc(sizeof(struct timeval) );
if(! current_timeval)
	{
	fprintf(stdout, "could not allocate space for current_timeval\n");

	exit(1);
	}

/*  start the subtitle routines */
if(! title_init() )
	{
	fprintf(stdout, "Could not start subtitle display thread\n");

	exit(1);
	}

exit(0);
} /* end function main */

==> osdplay-0.4.tgz: osdplay-0.4/osdplay.c <==
/*
osdplay  copyright 2003 Jan Panteltje.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#include "osdplay.h"
#include "osdplay.h"

FILE *optr;

int print_usage()
{
fprintf(stdout, "\
Usage:          osdplay [-d] [-h] [-l] [-o offset_milliseconds] -p projectname [-s]\n\n\
-b              force black and white subtitles\n\
-d              debug (prints functions and arguments)\n\
-h              help (this help)\n\
-l              activate logo\n\
-o offset       offset in milliseconds\n\
-p projectname  projectname, filename used is ~/.subtitles/projectname/projectname.sub\n\
-s factor       factor is speed multiplier (float) example -s 1.003\n\
-t              fast test mode (no sync)\n\
-u devicename   name of OSD device, for example /dev/ost/osd0 (default is /dev/ost/osdn, n = 0 to 9)\n\
-v              input file in in vob2sub format (made with submux-dvd)\n\
");

return 1;
} /* end function print_usage */


int main(int argc, char **argv)
{
int a;

fprintf(stdout, "\nPanteltje osdplay-%s\n\n", VERSION);

/* defaults */
speed_factor = 1.0;
/* end defaults */

while(1)
	{
	a = getopt(argc, argv, "bdhlo:p:s:tvu:");
	if(a == -1) break;

	switch(a)
		{
        case -1:
        	break;
		case 'b':
			bw_flag = 1;
			break;
		case 'd':
			debug_flag = 1;
			break;
		case 'h':
			print_usage();
			exit(1);
			break;
		case 'l':
			logo_flag = 1;
			break;
		case 'o':
			offset_milliseconds = atol(optarg);
			break;
		case 'p':
			selected_project = strsave(optarg);
			if(! selected_project)
				{
				fprintf(stdout, "could not alloce space for selected_project aborting\n");

				exit(1);
				}			
			break;
		case 's':
			speed_factor = atof(optarg);
			if(speed_factor <= 0.0)
				{
				fprintf(stdout,\
				"-c flag: speed_factor=%f, but cannot be zero or negative, aborting.\n",\
				speed_factor);
				
				exit(1);
				}

			break;
		case 't':
			no_sync_flag = 1;
			break;
		case 'u':
			osd_device_name = strsave(optarg);
			if(! osd_device_name)
				{
				fprintf(stdout, "Could not allocate space for osd_device_name, aborting\n");
				exit(1);
				}

			break;
		case 'v':
			vob2sub_flag = 1;
			break;
		case '?':
			if (isprint(optopt) )
 				{
 				fprintf(stdout, "Unknown option `-%c'.\n", optopt);
 				}
			else
				{
				fprintf(stdout, "Unknown option character `\\x%x'.\n",\
				optopt);
				}
			print_usage();

			exit(1);
			break;			
		default:
			print_usage();

			exit(1);
			break;
		}/* end switch a */
	}/* end while getopt() */

if(! selected_project && ! logo_flag)
	{
	print_usage();

	exit(1);
	}

/* report special situations */
if(offset_milliseconds != 0) fprintf(stdout, "using delay %ld milliseconds\n", offset_milliseconds);
if(speed_factor != 1.0) fprintf(stdout, "using speed %f x\n", speed_factor);
if(bw_flag) fprintf(stdout, "forcing black and white subtitles\n");
if(no_sync_flag) fprintf(stdout, "using test mode!!!\n");
if(vob2sub_flag) fprintf(stdout, "expecting vob2sub format .sub file\n");
if(logo_flag) fprintf(stdout, "logo activated\n");
if(debug_flag) fprintf(stdout, "debug_mode activated\n");
if(osd_device_name) fprintf(stdout, "using osd device %s\n", osd_device_name); 
userinfo = getpwuid(getuid() );

/* get home directory */ 
home_dir = strsave(userinfo -> pw_dir);
user_name = strsave(userinfo -> pw_name);

start_timeval = malloc(sizeof(struct timeval) );
if(! start_timeval)
	{
	fprintf(stdout, "could not allocate space for start_timeval\n");

	exit(1);
	}

current_timeval = malloc(sizeof(struct timeval) );
if(! current_timeval)
	{
	fprintf(stdout, "could not allocate space for current_timeval\n");

	exit(1);
	}

/*  start the subtitle routines */
if(! title_init() )
	{
	fprintf(stdout, "Could not start subtitle display\n");

	exit(1);
	}

exit(0);
} /* end function main */
